@@ -6,7 +6,8 @@ class DataMergeWidget(Input):
     input_type = 'textarea'
     crispy_kwargs = {'label_class': 'col-3 col-form-label-sm', 'field_class': 'col-12 input-group-sm'}
 
-    def __init__(self, data_merge_data=None):
+    def __init__(self, data_merge_data=None, height=150):
+        self.height = height
         super().__init__()
         self.data_merge_data = data_merge_data
 
@@ -18,5 +19,7 @@ class DataMergeWidget(Input):
             context['data_merge'] = None
         else:
             context['data_merge'] = self.data_merge_data.build_menus()
+
         context['disabled'] = attrs is not None and attrs.get('disabled', False)
+        context['height'] = self.height
         return context
