@@ -4,6 +4,7 @@ from django.utils.dates import MONTHS
 from django_datatables.columns import DatatableColumn, NoHeadingColumn, ManyToManyColumn
 from django_datatables.model_def import DatatableModel
 from time_stamped_model.models import TimeStampedModel
+from django_modals.model_fields.colour import ColourField
 
 from advanced_report_builder.globals import DISPLAY_OPTION_CHOICES, DISPLAY_OPTION_2_PER_ROW, DISPLAY_OPTION_NONE, \
     DISPLAY_OPTION_CLASSES, ANNOTATION_VALUE_CHOICES, ANNOTATIONS_CHOICES, ANNOTATION_CHOICE_COUNT, \
@@ -24,8 +25,8 @@ class Target(TimeStampedModel):
     slug = models.SlugField(unique=True)
     name = models.CharField(max_length=64)
     target_type = models.PositiveSmallIntegerField(choices=TARGET_TYPE_CHOICES)
-    colour = models.CharField(max_length=10, null=True, blank=True,
-                              help_text='The colour when it gets displayed on a report')
+    colour = ColourField(null=True, blank=True,
+                         help_text='The colour when it gets displayed on a report')
     default_value = models.IntegerField(blank=True, null=True)
     default_percentage = models.FloatField(blank=True, null=True)
     overridden = models.BooleanField(default=False)
@@ -235,7 +236,8 @@ class SingleValueReport(Report):
     SINGLE_VALUE_TYPE_COUNT_AND_SUM = 3
     SINGLE_VALUE_TYPE_PERCENT = 4
     SINGLE_VALUE_TYPE_PERCENT_FROM_COUNT = 5
-    SINGLE_VALUE_TYPE_AVERAGE = 6
+    SINGLE_VALUE_TYPE_AVERAGE_SUM_FROM_COUNT = 6
+    SINGLE_VALUE_TYPE_AVERAGE_SUM_OVER_TIME = 7
 
     SINGLE_VALUE_TYPE_CHOICES = (
         (SINGLE_VALUE_TYPE_COUNT, 'Count'),
@@ -243,10 +245,11 @@ class SingleValueReport(Report):
         (SINGLE_VALUE_TYPE_COUNT_AND_SUM, 'Count & Sum'),
         (SINGLE_VALUE_TYPE_PERCENT, 'Percent'),
         (SINGLE_VALUE_TYPE_PERCENT_FROM_COUNT, 'Percent from Count'),
-        (SINGLE_VALUE_TYPE_AVERAGE, 'Average')
+        (SINGLE_VALUE_TYPE_AVERAGE_SUM_FROM_COUNT, 'Average Sum from Count'),
+        (SINGLE_VALUE_TYPE_AVERAGE_SUM_OVER_TIME, 'Average Sum over Time')
     )
 
-    tile_colour = models.CharField(max_length=10, blank=True, null=True)
+    tile_colour = ColourField(blank=True, null=True)
     field = models.CharField(max_length=200, blank=True, null=True)  # denominator
     numerator = models.CharField(max_length=200, blank=True, null=True)
     single_value_type = models.PositiveSmallIntegerField(choices=SINGLE_VALUE_TYPE_CHOICES,
@@ -256,6 +259,10 @@ class SingleValueReport(Report):
     show_breakdown = models.BooleanField(default=False)
     breakdown_fields = models.JSONField(null=True, blank=True)
 
+    average_scale = models.PositiveSmallIntegerField(choices=ANNOTATION_VALUE_CHOICES, blank=True, null=True)
+    average_start_period = models.PositiveSmallIntegerField(blank=True, null=True)
+    average_end_period = models.PositiveSmallIntegerField(blank=True, null=True)
+
     def is_percentage(self):
         return self.single_value_type in [self.SINGLE_VALUE_TYPE_PERCENT,
                                           self.SINGLE_VALUE_TYPE_PERCENT_FROM_COUNT]
@@ -271,8 +278,22 @@ class BarChartReport(Report):
         (BAR_CHART_ORIENTATION_HORIZONTAL, 'Horizontal')
     )
 
+    DATE_FIELD_SINGLE = 1
+    DATE_FIELD_RANGE = 2
+
+    DATE_FIELD_CHOICES = (
+        (DATE_FIELD_SINGLE, 'Single'),
+        (DATE_FIELD_RANGE, 'Range')
+    )
+
     axis_scale = models.PositiveSmallIntegerField(choices=ANNOTATION_VALUE_CHOICES)
+
+    date_field_type = models.PositiveSmallIntegerField(choices=DATE_FIELD_CHOICES,
+                                                       default=DATE_FIELD_SINGLE)
+
     date_field = models.CharField(max_length=200)
+    end_date_field = models.CharField(max_length=200, blank=True, null=True)
+
     axis_value_type = models.PositiveSmallIntegerField(choices=ANNOTATIONS_CHOICES,
                                                        default=ANNOTATION_CHOICE_COUNT, null=True, blank=True)
     fields = models.JSONField(null=True, blank=True)
@@ -285,6 +306,9 @@ class BarChartReport(Report):
     show_totals = models.BooleanField(default=False)
     show_blank_dates = models.BooleanField(default=True)
 
+    show_breakdown = models.BooleanField(default=False)
+    breakdown_fields = models.JSONField(null=True, blank=True)
+
     def is_orientation_vertical(self):
         return self.bar_chart_orientation == self.BAR_CHART_ORIENTATION_VERTICAL
 
