@@ -21,7 +21,8 @@ from advanced_report_builder.globals import DATE_FIELDS, NUMBER_FIELDS, ANNOTATI
     DATE_FORMAT_TYPES, CURRENCY_COLUMNS, LINK_COLUMNS
 from advanced_report_builder.models import TableReport, ReportQuery, ReportType
 from advanced_report_builder.toggle import RBToggle
-from advanced_report_builder.utils import split_attr, get_field_details, encode_attribute, decode_attribute
+from advanced_report_builder.utils import split_attr, get_field_details, encode_attribute, decode_attribute, \
+    get_report_builder_class
 from advanced_report_builder.views.charts_base import ChartBaseFieldForm
 from advanced_report_builder.views.modals_base import QueryBuilderModalBaseMixin, QueryBuilderModalBase
 
@@ -100,7 +101,8 @@ class TableModal(QueryBuilderModalBase):
                   FieldEx('page_length', template='django_modals/fields/label_checkbox.html'),
                   FieldEx('table_fields',
                           template='advanced_report_builder/select_column.html',
-                          extra_context={'select_column_url': url}),
+                          extra_context={'select_column_url': url,
+                                         'command_prefix': ''}),
                   FieldEx('pivot_fields',
                           template='advanced_report_builder/datatables/select_pivot.html',
                           extra_context={'select_column_url': pivot_url}),
@@ -268,8 +270,13 @@ class TableFieldForm(ChartBaseFieldForm):
         report_type, base_model = self.get_report_type_details()
 
         self.fields['title'] = CharField(initial=data['title'])
-
         data_attr = split_attr(data)
+        self.fields['display_heading'] = BooleanField(required=False,
+                                                      widget=RBToggle(),
+                                                      label='Display heading')
+        if int(data_attr.get('display_heading', 1)) == 1:
+            self.fields['display_heading'].initial = True
+
         if self.django_field is not None and isinstance(self.django_field, DATE_FIELDS):
             self.fields['annotations_value'] = ChoiceField(choices=[(0, '-----')] + ANNOTATION_VALUE_CHOICES,
                                                            required=False)
@@ -283,9 +290,11 @@ class TableFieldForm(ChartBaseFieldForm):
                                                           required=False)
             if 'annotations_type' in data_attr:
                 self.fields['annotations_type'].initial = data_attr['annotations_type']
-            self.fields['show_totals'] = BooleanField(required=False, widget=RBToggle())
+            self.fields['show_table_totals'] = BooleanField(required=False,
+                                                            widget=RBToggle(),
+                                                            label='Show totals')
             if 'show_totals' in data_attr and data_attr['show_totals'] == '1':
-                self.fields['show_totals'].initial = True
+                self.fields['show_table_totals'].initial = True
             self.fields['decimal_places'] = IntegerField()
             self.fields['decimal_places'].initial = int(data_attr.get('decimal_places', 0))
             self.fields['has_filter'] = BooleanField(required=False, widget=RBToggle())
@@ -299,10 +308,11 @@ class TableFieldForm(ChartBaseFieldForm):
 
             self.fields['multiple_columns'] = BooleanField(required=False, widget=RBToggle())
 
-            report_builder_fields = getattr(base_model, report_type.report_builder_class_name, None)
+            report_builder_class = get_report_builder_class(model=base_model,
+                                                            report_type=report_type)
             fields = []
             self._get_query_builder_foreign_key_fields(base_model=base_model,
-                                                       report_builder_fields=report_builder_fields,
+                                                       report_builder_class=report_builder_class,
                                                        fields=fields)
 
             self.fields['multiple_column_field'] = ChoiceField(choices=fields, required=False)
@@ -311,9 +321,11 @@ class TableFieldForm(ChartBaseFieldForm):
                 self.fields['multiple_columns'].initial = True
                 self.fields['multiple_column_field'].initial = data_attr.get('multiple_column_field')
         elif isinstance(self.col_type_override, CURRENCY_COLUMNS):
-            self.fields['show_totals'] = BooleanField(required=False, widget=RBToggle())
+            self.fields['show_table_totals'] = BooleanField(required=False,
+                                                            widget=RBToggle(),
+                                                            label='Show totals')
             if 'show_totals' in data_attr and data_attr['show_totals'] == '1':
-                self.fields['show_totals'].initial = True
+                self.fields['show_table_totals'].initial = True
         elif isinstance(self.col_type_override, LINK_COLUMNS):
             self.fields['link_html'] = CharField(required=False)
             if 'link_html' in data_attr:
@@ -334,6 +346,12 @@ class TableFieldForm(ChartBaseFieldForm):
     def get_additional_attributes(self):
         attributes = []
         self.get_report_type_details()
+
+        if self.cleaned_data['display_heading']:
+            attributes.append('display_heading-1')
+        else:
+            attributes.append('display_heading-0')
+
         if self.django_field is not None and isinstance(self.django_field, DATE_FIELDS):
             if self.cleaned_data['annotations_value']:
                 attributes.append(f'annotations_value-{self.cleaned_data["annotations_value"]}')
@@ -342,7 +360,7 @@ class TableFieldForm(ChartBaseFieldForm):
         elif self.django_field is not None and isinstance(self.django_field, NUMBER_FIELDS):
             if int(self.cleaned_data['annotations_type']) != 0:
                 attributes.append(f'annotations_type-{self.cleaned_data["annotations_type"]}')
-            if self.cleaned_data['show_totals'] and self.cleaned_data["show_totals"]:
+            if self.cleaned_data['show_table_totals']:
                 attributes.append('show_totals-1')
             if self.cleaned_data['decimal_places'] > 0:
                 attributes.append(f'decimal_places-{self.cleaned_data["decimal_places"]}')
@@ -355,7 +373,7 @@ class TableFieldForm(ChartBaseFieldForm):
                     attributes.append('multiple_columns-1')
                     attributes.append(f'multiple_column_field-{self.cleaned_data["multiple_column_field"]}')
         elif isinstance(self.col_type_override, CURRENCY_COLUMNS):
-            if self.cleaned_data['show_totals'] and self.cleaned_data["show_totals"]:
+            if self.cleaned_data['show_table_totals']:
                 attributes.append('show_totals-1')
         elif isinstance(self.col_type_override, LINK_COLUMNS):
             if self.cleaned_data['link_css']:
@@ -419,8 +437,9 @@ class TableFieldModal(QueryBuilderModalBaseMixin, FormModal):
             ])
 
             return ['title',
+                    'display_heading',
                     'annotations_type',
-                    'show_totals',
+                    'show_table_totals',
                     'decimal_places',
                     Div(FieldEx('has_filter',
                                 template='django_modals/fields/label_checkbox.html',
@@ -439,7 +458,7 @@ class TableFieldModal(QueryBuilderModalBaseMixin, FormModal):
                     ]
         elif isinstance(col_type_override, CURRENCY_COLUMNS):
             return ['title',
-                    'show_totals']
+                    'show_table_totals']
         elif isinstance(col_type_override, LINK_COLUMNS):
             return ['title',
                     'link_css',
