@@ -3,6 +3,7 @@ import json
 from django.core.exceptions import ValidationError
 from django.db.models import Count, Sum, ExpressionWrapper, FloatField
 from django.db.models.functions import Coalesce, NullIf
+from django.forms import ChoiceField
 from django.shortcuts import get_object_or_404
 from django.urls import reverse
 from django_datatables.datatables import DatatableTable
@@ -11,16 +12,16 @@ from django_modals.fields import FieldEx
 from django_modals.helper import show_modal
 from django_modals.modals import Modal
 from django_modals.processes import PROCESS_EDIT_DELETE, PERMISSION_OFF
-from django_modals.widgets.colour_picker import ColourPickerWidget
 from django_modals.widgets.select2 import Select2Multiple
 from django_modals.widgets.widgets import Toggle
 
 from advanced_report_builder.columns import ReportBuilderNumberColumn
 from advanced_report_builder.exceptions import ReportError
 from advanced_report_builder.globals import NUMBER_FIELDS, ANNOTATION_CHOICE_SUM, \
-    ANNOTATION_CHOICE_AVG
+    ANNOTATION_CHOICE_AVERAGE_SUM_FROM_COUNT
 from advanced_report_builder.models import SingleValueReport, ReportType
-from advanced_report_builder.utils import get_field_details
+from advanced_report_builder.utils import get_field_details, get_report_builder_class
+from advanced_report_builder.variable_date import VariableDate
 from advanced_report_builder.views.charts_base import ChartBaseView
 from advanced_report_builder.views.datatables.modal import TableFieldModal, TableFieldForm
 from advanced_report_builder.views.datatables.utils import TableUtilsMixin
@@ -37,10 +38,11 @@ class SingleValueView(ChartBaseView):
         self.chart_report = self.report.singlevaluereport
         return super().dispatch(request, *args, **kwargs)
 
-    def _process_aggregations(self, fields, aggregations_type=ANNOTATION_CHOICE_SUM):
+    def _process_aggregations(self, fields, aggregations_type=ANNOTATION_CHOICE_SUM, divider=None):
         field = self.chart_report.field
         base_model = self.chart_report.get_base_modal()
-        report_builder_class = getattr(base_model, self.chart_report.report_type.report_builder_class_name, None)
+        report_builder_class = get_report_builder_class(model=base_model,
+                                                        report_type=self.chart_report.report_type)
 
         django_field, col_type_override, _, _ = get_field_details(base_model=base_model,
                                                                   field=field,
@@ -56,7 +58,8 @@ class SingleValueView(ChartBaseView):
                                   fields=fields,
                                   col_type_override=col_type_override,
                                   decimal_places=self.chart_report.decimal_places,
-                                  convert_currency_fields=True)
+                                  convert_currency_fields=True,
+                                  divider=divider)
         else:
             raise ReportError('not a number field')
 
@@ -137,7 +140,8 @@ class SingleValueView(ChartBaseView):
         denominator_field = self.chart_report.field
         numerator_field = self.chart_report.numerator
         base_model = self.chart_report.get_base_modal()
-        report_builder_class = getattr(base_model, self.chart_report.report_type.report_builder_class_name, None)
+        report_builder_class = get_report_builder_class(model=base_model,
+                                                        report_type=self.chart_report.report_type)
 
         deno_django_field, denominator_col_type_override, _, _ = get_field_details(
             base_model=base_model,
@@ -205,8 +209,13 @@ class SingleValueView(ChartBaseView):
         elif single_value_type == SingleValueReport.SINGLE_VALUE_TYPE_COUNT_AND_SUM:
             self._get_count(fields=fields)
             self._process_aggregations(fields=fields, aggregations_type=ANNOTATION_CHOICE_SUM)
-        elif single_value_type == SingleValueReport.SINGLE_VALUE_TYPE_AVERAGE:
-            self._process_aggregations(fields=fields, aggregations_type=ANNOTATION_CHOICE_AVG)
+        elif single_value_type == SingleValueReport.SINGLE_VALUE_TYPE_AVERAGE_SUM_FROM_COUNT:
+            self._process_aggregations(fields=fields, aggregations_type=ANNOTATION_CHOICE_AVERAGE_SUM_FROM_COUNT)
+        elif single_value_type == SingleValueReport.SINGLE_VALUE_TYPE_AVERAGE_SUM_OVER_TIME:
+            divider = self.get_period_divider(annotation_value_choice=self.chart_report.average_scale,
+                                              start_date_type=self.chart_report.average_start_period,
+                                              end_date_type=self.chart_report.average_end_period)
+            self._process_aggregations(fields=fields, aggregations_type=ANNOTATION_CHOICE_SUM, divider=divider)
         elif single_value_type == SingleValueReport.SINGLE_VALUE_TYPE_PERCENT:
             self._process_percentage(fields=fields)
         elif single_value_type == SingleValueReport.SINGLE_VALUE_TYPE_PERCENT_FROM_COUNT:
@@ -215,6 +224,8 @@ class SingleValueView(ChartBaseView):
 
     def set_prefix(self):
         self.table.prefix = self.chart_report.prefix
+        if self.table.prefix:
+            self.table.prefix += ' '
 
     def get_context_data(self, **kwargs):
         context = super().get_context_data(**kwargs)
@@ -228,7 +239,7 @@ class SingleValueView(ChartBaseView):
 
     def get_breakdown_url(self):
         if self.table.single_value.show_breakdown:
-            return show_modal('advanced_report_builder:show_breakdown_modal',
+            return show_modal('advanced_report_builder:single_value_show_breakdown_modal',
                               'pk-',
                               self.table.single_value.id,
                               '-enable_links-',
@@ -253,8 +264,7 @@ class SingleValueModal(QueryBuilderModalBase):
     process = PROCESS_EDIT_DELETE
     permission_delete = PERMISSION_OFF
     model = SingleValueReport
-    widgets = {'tile_colour': ColourPickerWidget,
-               'report_tags': Select2Multiple,
+    widgets = {'report_tags': Select2Multiple,
                'show_breakdown': Toggle(attrs={'data-onstyle': 'success', 'data-on': 'YES', 'data-off': 'NO'})}
 
     form_fields = ['name',
@@ -263,6 +273,9 @@ class SingleValueModal(QueryBuilderModalBase):
                    'report_tags',
                    ('single_value_type', {'label': 'Value type'}),
                    ('numerator', {'label': 'Numerator field'}),
+                   'average_scale',
+                   'average_start_period',
+                   'average_end_period',
                    'field',
                    'prefix',
                    'tile_colour',
@@ -292,6 +305,15 @@ class SingleValueModal(QueryBuilderModalBase):
              'values': {SingleValueReport.SINGLE_VALUE_TYPE_PERCENT: ('html', 'Denominator field')},
              'default': ('html', 'Field')},
 
+            {'selector': '#div_id_average_scale',
+             'values': {SingleValueReport.SINGLE_VALUE_TYPE_AVERAGE_SUM_OVER_TIME: 'show'},
+             'default': 'hide'},
+            {'selector': '#div_id_average_start_period',
+             'values': {SingleValueReport.SINGLE_VALUE_TYPE_AVERAGE_SUM_OVER_TIME: 'show'},
+             'default': 'hide'},
+            {'selector': '#div_id_average_end_period',
+             'values': {SingleValueReport.SINGLE_VALUE_TYPE_AVERAGE_SUM_OVER_TIME: 'show'},
+             'default': 'hide'},
         ])
 
         form.add_trigger('show_breakdown', 'onchange', [
@@ -324,6 +346,10 @@ class SingleValueModal(QueryBuilderModalBase):
         form.fields['notes'].widget.attrs['rows'] = 3
         url = reverse('advanced_report_builder:single_value_field_modal',
                       kwargs={'slug': 'selector-99999-data-FIELD_INFO-report_type_id-REPORT_TYPE_ID'})
+
+        range_type_choices = VariableDate.RANGE_TYPE_CHOICES
+        form.fields['average_start_period'] = ChoiceField(required=False, choices=range_type_choices)
+        form.fields['average_end_period'] = ChoiceField(required=False, choices=range_type_choices)
         return ('name',
                 'notes',
                 'report_type',
@@ -331,6 +357,9 @@ class SingleValueModal(QueryBuilderModalBase):
                 'single_value_type',
                 'numerator',
                 'field',
+                'average_scale',
+                'average_start_period',
+                'average_end_period',
                 'prefix',
                 FieldEx('extra_query_data',
                         template='advanced_report_builder/query_builder.html',
@@ -340,7 +369,8 @@ class SingleValueModal(QueryBuilderModalBase):
                 'show_breakdown',
                 FieldEx('breakdown_fields',
                         template='advanced_report_builder/select_column.html',
-                        extra_context={'select_column_url': url}),
+                        extra_context={'select_column_url': url,
+                                       'command_prefix': ''}),
                 FieldEx('query_data',
                         template='advanced_report_builder/query_builder.html')
                 )
@@ -357,11 +387,20 @@ class SingleValueModal(QueryBuilderModalBase):
 
     # noinspection PyUnusedLocal
     def clean(self, form, cleaned_data):
-        if (cleaned_data['single_value_type'] not in [SingleValueReport.SINGLE_VALUE_TYPE_COUNT,
-                                                      SingleValueReport.SINGLE_VALUE_TYPE_PERCENT_FROM_COUNT] and
+        single_value_type = cleaned_data['single_value_type']
+        if (single_value_type not in [SingleValueReport.SINGLE_VALUE_TYPE_COUNT,
+                                      SingleValueReport.SINGLE_VALUE_TYPE_PERCENT_FROM_COUNT] and
                 not cleaned_data['field']):
             raise ValidationError("Please select a field")
 
+        if single_value_type == SingleValueReport.SINGLE_VALUE_TYPE_AVERAGE_SUM_OVER_TIME:
+            if cleaned_data['average_scale'] is None:
+                form.add_error('average_scale', "Please select a time scale")
+            if cleaned_data['average_start_period'] is None:
+                form.add_error('average_start_period', "Please select a start period")
+            if cleaned_data['average_end_period'] is None:
+                form.add_error('average_end_period', "Please select a end period")
+
     def ajax_get_fields(self, **kwargs):
         report_type_id = kwargs['report_type']
         report_builder_fields, base_model = self.get_report_builder_class(report_type_id=report_type_id)
@@ -374,7 +413,7 @@ class SingleValueModal(QueryBuilderModalBase):
         return self.command_response('report_fields', data=json.dumps({'fields': fields, 'tables': tables}))
 
 
-class ShowBreakdownModal(TableUtilsMixin, Modal):
+class SingleValueShowBreakdownModal(TableUtilsMixin, Modal):
     button_container_class = 'text-center'
     size = 'xl'
 
@@ -392,8 +431,8 @@ class ShowBreakdownModal(TableUtilsMixin, Modal):
         table = self.add_table(base_model=base_model)
         table.extra_filters = self.extra_filters
         table_fields = single_value_report.breakdown_fields
-        report_builder_class = getattr(base_model,
-                                       self.table_report.report_type.report_builder_class_name, None)
+        report_builder_class = get_report_builder_class(model=base_model,
+                                                        report_type=self.table_report.report_type)
         fields_used = set()
         self.process_query_results(report_builder_class=report_builder_class,
                                    table=table,
@@ -411,7 +450,6 @@ class ShowBreakdownModal(TableUtilsMixin, Modal):
         return table.render()
 
 
-
 class SingleValueTableFieldForm(TableFieldForm):
     cancel_class = 'btn-secondary modal-cancel'
 
